/****************************************************************************
** Meta object code from reading C++ file 'brightnesscontrol.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../powerdevil-6.7.1/daemon/actions/bundled/brightnesscontrol.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'brightnesscontrol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PowerDevil14BundledActions17BrightnessControlE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerDevil::BundledActions::BrightnessControl::qt_create_metaobjectdata<qt_meta_tag_ZN10PowerDevil14BundledActions17BrightnessControlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerDevil::BundledActions::BrightnessControl",
        "D-Bus Interface",
        "org.kde.Solid.PowerManagement.Actions.BrightnessControl",
        "brightnessChanged",
        "",
        "value",
        "brightnessMaxChanged",
        "valueMax",
        "brightnessMinChanged",
        "valueMin",
        "increaseBrightness",
        "increaseBrightnessSmall",
        "decreaseBrightness",
        "decreaseBrightnessSmall",
        "setBrightness",
        "percent",
        "setBrightnessSilent",
        "onBrightnessChangedFromController",
        "BrightnessLogic::BrightnessInfo",
        "brightnessInfo",
        "ScreenBrightnessController::IndicatorHint",
        "hint"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'brightnessChanged'
        QtMocHelpers::SignalData<void(int)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'brightnessMaxChanged'
        QtMocHelpers::SignalData<void(int)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'brightnessMinChanged'
        QtMocHelpers::SignalData<void(int)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'increaseBrightness'
        QtMocHelpers::SlotData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'increaseBrightnessSmall'
        QtMocHelpers::SlotData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'decreaseBrightness'
        QtMocHelpers::SlotData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'decreaseBrightnessSmall'
        QtMocHelpers::SlotData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setBrightness'
        QtMocHelpers::SlotData<void(int)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'setBrightnessSilent'
        QtMocHelpers::SlotData<void(int)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'onBrightnessChangedFromController'
        QtMocHelpers::SlotData<void(const BrightnessLogic::BrightnessInfo &, ScreenBrightnessController::IndicatorHint)>(17, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 20, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<BrightnessControl, qt_meta_tag_ZN10PowerDevil14BundledActions17BrightnessControlE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PowerDevil::BundledActions::BrightnessControl::staticMetaObject = { {
    QMetaObject::SuperData::link<PowerDevil::Action::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil14BundledActions17BrightnessControlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil14BundledActions17BrightnessControlE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PowerDevil14BundledActions17BrightnessControlE_t>.metaTypes,
    nullptr
} };

void PowerDevil::BundledActions::BrightnessControl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BrightnessControl *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->brightnessChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->brightnessMaxChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->brightnessMinChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->increaseBrightness(); break;
        case 4: _t->increaseBrightnessSmall(); break;
        case 5: _t->decreaseBrightness(); break;
        case 6: _t->decreaseBrightnessSmall(); break;
        case 7: _t->setBrightness((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->setBrightnessSilent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->onBrightnessChangedFromController((*reinterpret_cast<std::add_pointer_t<BrightnessLogic::BrightnessInfo>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ScreenBrightnessController::IndicatorHint>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BrightnessControl::*)(int )>(_a, &BrightnessControl::brightnessChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BrightnessControl::*)(int )>(_a, &BrightnessControl::brightnessMaxChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BrightnessControl::*)(int )>(_a, &BrightnessControl::brightnessMinChanged, 2))
            return;
    }
}

const QMetaObject *PowerDevil::BundledActions::BrightnessControl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerDevil::BundledActions::BrightnessControl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil14BundledActions17BrightnessControlE_t>.strings))
        return static_cast<void*>(this);
    return PowerDevil::Action::qt_metacast(_clname);
}

int PowerDevil::BundledActions::BrightnessControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PowerDevil::Action::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void PowerDevil::BundledActions::BrightnessControl::brightnessChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PowerDevil::BundledActions::BrightnessControl::brightnessMaxChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PowerDevil::BundledActions::BrightnessControl::brightnessMinChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
